Summary:	A set of tools to display and debug your BIOS ACPI tables
Name:		acpica
Version:	20141107
Release:	3
License:	GPLv2+
Group:		System/Kernel and hardware
Url:		http://acpica.org
# Sources and patches are takes from Rawhide
Source0:        https://acpica.org/sites/acpica/files/acpica-unix2-%{version}.tar.gz
Source1:        https://acpica.org/sites/acpica/files/acpitests-unix-%{version}.tar.gz
Source2:        README
Source3:        iasl.1
Source4:        acpibin.1
Source5:        acpidump.1
Source6:        acpiexec.1
Source7:        acpihelp.1
Source8:        acpinames.1
Source9:        acpisrc.1
Source10:       acpixtract.1
Source11:       badcode.asl.result
Source12:       grammar.asl.result
Source13:       run-misc-tests.sh
Source14:       COPYING

Patch0:         debian-big_endian.patch
Patch1:         debian-unaligned.patch
Patch2:         name-miscompare.patch
Patch3:         aapits-linux.patch
Patch4:         asllookup-miscompare.patch
Patch5:         aapits-makefile.patch
Patch6:		re-enable-big-endian.patch
Patch7:		OPT_LDFLAGS.patch
BuildRequires:	bison
BuildRequires:	flex
#BuildRequires:	patchutils
BuildRequires:	glibc-devel

Obsoletes:	pmtools =< 20071116
Obsoletes:	acpica =< 20130517
Obsoletes:	iasl =< 20090422

Provides:       pmtools = %{EVRD}
Provides:       iasl = %{EVRD}

%description
The included tools share the same code as it is used in the ACPI
implementation of the kernel. The code of the acpica project is exactly
the same as the ACPI parser and interpreter code of the kernel and the
code gets synced regularly from the acpica project into the kernel.
E.g. if you identify bugs in the kernel's ACPI implementation it might
be easier to debug them in userspace if possible. If the bug is part of
the acpica code, it has to be submitted to the acpica project to get
merged into the mainline kernel sources.

%prep
%setup -q -n acpica-unix2-%{version}
%setup -q -T -D -a 1 -n acpica-unix2-%{version}
gzip -dc %{SOURCE1} | tar -x --strip-components=1 -f -

%patch0 -p1 -b .debian-big_endian
%patch1 -p1 -b .debian-unaligned
%patch2 -p1 -b .name-miscompare
%patch3 -p1 -b .aapits-linux
%patch4 -p1 -b .asllookup-miscompare
%patch5 -p1 -b .aapits-makefile
%patch6 -p1 -b .re-enable-big-endian
%patch7 -p1 -b .OPT_LDFLAGS

cp -p %{SOURCE2} README
cp -p %{SOURCE3} iasl.1
cp -p %{SOURCE4} acpibin.1
cp -p %{SOURCE5} acpidump.1
cp -p %{SOURCE6} acpiexec.1
cp -p %{SOURCE7} acpihelp.1
cp -p %{SOURCE8} acpinames.1
cp -p %{SOURCE9} acpisrc.1
cp -p %{SOURCE10} acpixtract.1
cp -p %{SOURCE11} badcode.asl.result
cp -p %{SOURCE12} grammar.asl.result
cp -p %{SOURCE13} tests/run-misc-tests.sh
chmod a+x tests/run-misc-tests.sh
cp -p %{SOURCE14} COPYING

# spurious executable permissions on text files in upstream
chmod a-x changes.txt
chmod a-x source/compiler/new_table.txt



%build
# forget parallel here.Sflo
make OPT_CFLAGS="%{optflags}" OPT_LDFLAGS="$LDFLAGS"

%install
# Install the binaries
mkdir -p %{buildroot}%{_bindir}
install -pD generate/unix/bin*/* %{buildroot}%{_bindir}/
mv %{buildroot}%{_bindir}/acpidump %{buildroot}%{_bindir}/acpidump-acpica
mv %{buildroot}%{_bindir}/acpixtract %{buildroot}%{_bindir}/acpixtract-acpica

# Install the man pages
mkdir -p %{buildroot}%{_mandir}/man1
install -pDm 0644 -p -D *.1 %{buildroot}%{_mandir}/man1/
mv %{buildroot}%{_mandir}/man1/acpixtract.1 \
   %{buildroot}%{_mandir}/man1/acpixtract-acpica.1
mv %{buildroot}%{_mandir}/man1/acpidump.1 \
   %{buildroot}%{_mandir}/man1/acpidump-acpica.1
   
   
# We already have iasl package
# sure we have iasl 20090422... usig this new one.Sflo
# rm -f %{buildroot}%{_bindir}/iasl  

# before run tests be sure to install even the manpages.Sflo  
%check
cd tests

# ASL tests
./aslts.sh                    
[ $? -eq 0 ] || exit 1

# API tests
cd aapits
make
cd asl
ASL=%{buildroot}%{_bindir}/iasl make
cd ../bin
./aapitsrun
[ $? -eq 0 ] || exit 1
cd ../..

# misc tests
./run-misc-tests.sh %{buildroot}%{_bindir} %{version}

# Template tests
cd templates
make
if [ -f diff.log ]
then
    if [ -s diff.log ]
    then
        exit 1                  
    fi
fi
cd ..

%post
alternatives --install %{_bindir}/acpixtract acpixtract \
                       %{_bindir}/acpixtract-acpica 120 \
               --slave %{_mandir}/man1/acpixtract.1.xz acpixtract.1.xz \
                       %{_mandir}/man1/acpixtract-acpica.1.xz

alternatives --install %{_bindir}/acpidump acpidump \
                       %{_bindir}/acpidump-acpica 120 \
               --slave %{_mandir}/man1/acpidump.1.xz acpidump.1.xz \
                       %{_mandir}/man1/acpidump-acpica.1.xz


%postun
if [ ! -e %{_bindir}/acpixtract-acpica ]
then
    alternatives --remove acpixtract %{_bindir}/acpixtract-acpica
fi
if [ ! -e %{_bindir}/acpidump-acpica ]
then
    alternatives --remove acpidump %{_bindir}/acpidump-acpica
fi

%files
%doc changes.txt source/compiler/new_table.txt
%doc README COPYING
%{_bindir}/*
%{_mandir}/*/*


%changelog

* Tue Aug 18 2015 Eugene Shatokhin <eugene.shatokhin@rosalab.ru> 20141107-3
- (57bcb34) Do not require patchutils from Contrib


